from enum import Enum


class Region(str, Enum):
    g = "global"
    kr = "kr"
    na = "na"
    eu = "euw"
    las = "las"
    lan = "lan"
    br = "br"
    jp = "jp"
    oce = "oce"
    sg = "sg"
    vn = "vn"
    tw = "th"
    th = "th"
    eune = "eune"
    ru = "ru"
