from enum import Enum


class Champion(str, Enum):
    aatrox = "aatrox"
    ahri = "ahri"
    akali = "akali"
    akshan = "akshan"
    alistar = "alistar"
    amumu = "amumu"
    anivia = "anivia"
    annie = "annie"
    aphelios = "aphelios"
    ashe = "ashe"
    aurelionsol = "aurelionsol"
    azir = "azir"
    bard = "bard"
    belveth = "belveth"
    blitzcrank = "blitzcrank"
    brand = "brand"
    braum = "braum"
    briar = "briar"
    caitlyn = "caitlyn"
    camille = "camille"
    cassiopeia = "cassiopeia"
    chogath = "chogath"
    corki = "corki"
    darius = "darius"
    diana = "diana"
    drmundo = "drmundo"
    draven = "draven"
    ekko = "ekko"
    elise = "elise"
    evelynn = "evelynn"
    ezreal = "ezreal"
    fiddlesticks = "fiddlesticks"
    fiora = "fiora"
    fizz = "fizz"
    galio = "galio"
    gangplank = "gangplank"
    garen = "garen"
    gnar = "gnar"
    gragas = "gragas"
    graves = "graves"
    gwen = "gwen"
    hecarim = "hecarim"
    heimerdinger = "heimerdinger"
    illaoi = "illaoi"
    irelia = "irelia"
    ivern = "ivern"
    janna = "janna"
    jarvaniv = "jarvaniv"
    jax = "jax"
    jayce = "jayce"
    jhin = "jhin"
    jinx = "jinx"
    kaisa = "kaisa"
    kalista = "kalista"
    karma = "karma"
    karthus = "karthus"
    kassadin = "kassadin"
    katarina = "katarina"
    kayle = "kayle"
    kayn = "kayn"
    kennen = "kennen"
    khazix = "khazix"
    kindred = "kindred"
    kled = "kled"
    kogmaw = "kogmaw"
    ksante = "ksante"
    leblanc = "leblanc"
    leesin = "leesin"
    leona = "leona"
    lillia = "lillia"
    lissandra = "lissandra"
    lucian = "lucian"
    lulu = "lulu"
    lux = "lux"
    malphite = "malphite"
    malzahar = "malzahar"
    maokai = "maokai"
    masteryi = "masteryi"
    millio = "millio"
    missfortune = "missfortune"
    mordekaiser = "mordekaiser"
    morgana = "morgana"
    naafiri = "naafiri"
    nami = "nami"
    nasus = "nasus"
    nautilus = "nautilus"
    neeko = "neeko"
    nidalee = "nidalee"
    nilah = "nilah"
    nocturne = "nocturne"
    nunu = "nunu"
    olaf = "olaf"
    orianna = "orianna"
    ornn = "ornn"
    pantheon = "pantheon"
    poppy = "poppy"
    pyke = "pyke"
    qiyana = "qiyana"
    quinn = "quinn"
    rakan = "rakan"
    rammus = "rammus"
    reksai = "reksai"
    rell = "rell"
    renata = "renata"
    renekton = "renekton"
    rengar = "rengar"
    riven = "riven"
    rumble = "rumble"
    ryze = "ryze"
    samira = "samira"
    sejuani = "sejuani"
    senna = "senna"
    seraphine = "seraphine"
    sett = "sett"
    shaco = "shaco"
    shen = "shen"
    shyvana = "shyvana"
    singed = "singed"
    sion = "sion"
    sivir = "sivir"
    skarner = "skarner"
    sona = "sona"
    soraka = "soraka"
    swain = "swain"
    sylas = "sylas"
    syndra = "syndra"
    tahmkench = "tahmkench"
    taliyah = "taliyah"
    talon = "talon"
    taric = "taric"
    teemo = "teemo"
    thresh = "thresh"
    tristana = "tristana"
    trundle = "trundle"
    tryndamere = "tryndamere"
    twistedfate = "twistedfate"
    twitch = "twitch"
    udyr = "udyr"
    urgot = "urgot"
    varus = "varus"
    vayne = "vayne"
    veigar = "veigar"
    velkoz = "velkoz"
    vex = "vex"
    vi = "vi"
    viego = "viego"
    viktor = "viktor"
    vladimir = "vladimir"
    volibear = "volibear"
    warwick = "warwick"
    wukong = "wukong"
    xayah = "xayah"
    xerath = "xerath"
    xinzhao = "xinzhao"
    yasuo = "yasuo"
    yone = "yone"
    yorick = "yorick"
    yuumi = "yuumi"
    zac = "zac"
    zed = "zed"
    zeri = "zeri"
    ziggs = "ziggs"
    zilean = "zilean"
    zoe = "zoe"
    zyra = "zyra"
